#!/bin/sh
#
# Ein Beispiel der DANTE-Edition
#
## Beispiel 12-04-3 auf Seite 602.
#
# Copyright (C) 2016 Herbert Voss
#
# It may be distributed and/or modified under the conditions
# of the LaTeX Project Public License, either version 1.3
# of this license or (at your option) any later version.
#
# See http://www.latex-project.org/lppl.txt for details.
#
# Running fc-list on Linux
#START

#STOP
#
#CODE->
fc-list Cambria
#<-CODE
